<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package FotoGraphy
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function fotography_body_classes( $classes ) {
    
    // Adds a class of group-blog to blogs with more than 1 published author.
    if ( is_multi_author() ) {
        $classes[] = 'group-blog';
    }

    if(is_singular(array('post','page'))){
        global $post;
        $post_sidebar = get_post_meta($post->ID, 'fotography_page_layouts', true);
        if(!$post_sidebar){
            $post_sidebar = 'rightsidebar';
        }
        $classes[] = $post_sidebar;
    }

    if( is_archive() || is_home() || is_search() ){
        $post_sidebar = get_theme_mod( 'fotography_archive_page_layout','rightsidebar' );
        if(!$post_sidebar){
            $post_sidebar = 'rightsidebar';
        }
        $classes[] = $post_sidebar;
    }

    if (esc_attr(get_theme_mod('fotography_homepage_slider_setting_option','disable')) == 'disable') {
        $classes[] = 'fg-noslider';
    }
    return $classes;
}
add_filter( 'body_class', 'fotography_body_classes' );





 if ( ! function_exists( 'fotography_page_title' ) ) :
    function fotography_page_title(){
    ?>
        <header class="page-header">
            <div class="foto-container">
                <?php $post_title = get_theme_mod('fotography_post_title_enable','yes');
                if($post_title == 'yes'){ ?>
                <h1><?php the_title(); ?></h1>
                <?php } ?>
                <?php echo fotography_breadcrumbs(); ?>
            </div>
        </header>
    <?php
    }
endif;
add_action('fotography_title','fotography_page_title');

function fotography_remove_div ( $menu ){
    return preg_replace( array( '#^<div[^>]*>#', '#</div>$#' ), '', $menu );
}
add_filter( 'wp_page_menu', 'fotography_remove_div' );

/**
 * Generate custom search form
 *
 * @param string $form Form HTML.
 * @return string Modified form HTML.
 */
function fotography_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform" class="searchform" action="' . home_url( '/' ) . '" >
    <div>
    <input type="text" value="' . get_search_query() . '" name="s" id="s" />
    <button id="searchsubmit" /><i class="fa fa-search"></i></button>
    </div>
    </form>';
 
    return $form;
}
add_filter( 'get_search_form', 'fotography_search_form' );


if(class_exists( 'WP_Customize_control')) :
class WP_Customize_Radioimage_Control extends WP_Customize_Control {
    public $type = 'radioimage';
    public function render_content() {
        $name = '_customize-radio-' . $this->id;
        ?>
        <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
        <div id="input_<?php echo esc_attr($this->id); ?>" class="image">
            <?php foreach ( $this->choices as $value => $label ) : ?>                
                    <label for="<?php echo esc_attr($this->id) . esc_attr($value); ?>">
                        <input class="image-select" type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" id="<?php echo esc_attr($this->id) . esc_attr($value); ?>" <?php $this->link(); checked( $this->value(), $value ); ?>>
                        <img src="<?php echo esc_html( $label ); ?>"/>
                    </label>
            <?php endforeach; ?>
        </div>
        <?php 
    }
}
endif;